# Lattice MachXO2 and MachXO3L

The {py:mod}`torii.platform.vendor.lattice.machxo_2_3l` module provides a base platform to support Lattice MachXO2 and MachXO3L devices with the[Diamond] toolchain.

```{eval-rst}

.. autoclass:: torii.platform.vendor.lattice.machxo_2_3l.MachXO2Platform
.. autoclass:: torii.platform.vendor.lattice.machxo_2_3l.MachXO3LPlatform

.. note:: Both of the above are aliases for the actual platform below, however only the aliased
          definitions are actually exported from the module for use.

.. autoclass:: torii.platform.vendor.lattice.machxo_2_3l.MachXO2Or3LPlatform

```

[Diamond]: https://www.latticesemi.com/latticediamond
